@@ -18,6 +18,8 @@
   @author Allen Winter \<winter@kde.org\>
 */
 #include "attachmenthandler.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "calendarsupport_debug.h"
 
 #include <Akonadi/CalendarUtils>
@@ -135,7 +137,7 @@ static QUrl tempFileForAttachment(const Attachment &attachment)
     QMimeDatabase db;
     QStringList patterns = db.mimeTypeForName(attachment.mimeType()).globPatterns();
     if (!patterns.empty()) {
-        s_tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/attachementview_XXXXXX") + patterns.first().remove(QLatin1Char('*')));
+        s_tempFile = new QTemporaryFile(QDir::tempPath() + "/attachementview_XXXXXX"_L1 + patterns.first().remove(QLatin1Char('*')));
     } else {
         s_tempFile = new QTemporaryFile();
     }
